@@ -4,9 +4,10 @@ class __result :
     accuracy = None
     precision = None
     recall = None
+    f1 = None
     all = None
 
-def report (a_accuracy,a_precision,a_recall) :
+def report (a_accuracy,a_precision,a_recall,a_f1) :
     """
     Use print() to show the result
     """
@@ -14,6 +15,7 @@ def report (a_accuracy,a_precision,a_recall) :
     loc_report = loc_report + 'Accuracy : ' + str(a_accuracy)
     loc_report = loc_report + "\n" +'Precision : ' + str(a_precision)
     loc_report = loc_report + "\n" +'Recall : ' + str(a_recall)
+    loc_report = loc_report + "\n" +'F1 : ' + str(a_f1)
     return loc_report
 
 def evals (a_y_true,a_y_pred) :
@@ -21,7 +23,8 @@ def evals (a_y_true,a_y_pred) :
     loc_result.accuracy = accuracy (a_y_true,a_y_pred)
     loc_result.precision = precision (a_y_true,a_y_pred)
     loc_result.recall = recall (a_y_true,a_y_pred)
-    loc_result.all = report (loc_result.accuracy,loc_result.precision,loc_result.recall)
+    loc_result.f1 = (2 * loc_result.precision * loc_result.recall) / (loc_result.precision + loc_result.recall)
+    loc_result.all = report (loc_result.accuracy,loc_result.precision,loc_result.recall,loc_result.f1)
     return loc_result
 
 def accuracy (a_y_true,a_y_pred) :
